<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="it_IT">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Opzioni veloci</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Disposizione estesa</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Uscite unificate</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Solo il primario</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Solo il secondario</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Impostazioni del monitor</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Impostazioni salvate</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Nessuna</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Inversiti</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Vero</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>MonitorInfo</name>
    <message>
        <source>Laptop LCD Monitor</source>
        <translation type="vanished">Monitor LCD portatile</translation>
    </message>
    <message>
        <source>External VGA Monitor</source>
        <translation type="vanished">Monitor esterno VGA</translation>
    </message>
    <message>
        <source>VGA Monitor</source>
        <translation type="vanished">Monitor VGA</translation>
    </message>
    <message>
        <source>External DVI Monitor</source>
        <translation type="vanished">Monitor esterno DVI</translation>
    </message>
    <message>
        <source>DVI Monitor</source>
        <translation type="vanished">Monitor DVI</translation>
    </message>
    <message>
        <source>TV</source>
        <translation type="vanished">TV</translation>
    </message>
    <message>
        <source>Default Monitor</source>
        <translation type="vanished">Monitor predefinito</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Finestra</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Mantieni i monitor collegati</translation>
    </message>
    <message>
        <source>Magnetic attraction</source>
        <translation type="vanished">Attrazione magnetica</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Impostazioni del monitor</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="vanished">Opzioni rapide</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="vanished">Mostra lo stesso schermo sullo schermo LCD del portatile e sul monitor esterno</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="vanished">Vista estesa</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="vanished">Spegni monitor lo schermo LCD del portatile e usa solo il monitor esterno</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="vanished">Spegni monitor esterno e usa lo schermo LCD del portatile</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Unify all monitors</source>
        <translation type="vanished">Unfica tutte le uscite</translation>
    </message>
    <message>
        <source>Monitor Position</source>
        <translation type="vanished">Posizione dello schermo</translation>
    </message>
    <message>
        <source>Primary monitor:</source>
        <translation type="vanished">Schermo principale:</translation>
    </message>
    <message>
        <source>Do you want to save changes?</source>
        <translation type="vanished">Vuoi salvare le modifiche?</translation>
    </message>
    <message>
        <source>Please, check your config before to save.</source>
        <translation type="vanished">Controlla la configurazione prima di salvare.</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Opzioni veloci</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Imposta la posizione</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Errore</translation>
    </message>
    <message>
        <source>Config can not be saved</source>
        <translation type="vanished">La configurazione non può essere salvata</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation>Impostazioni avanzate</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <source>Turn on</source>
        <translation type="vanished">Accendi</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Configurazione</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Risoluzione:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Abilita questo schermo</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Questo è il mio schermo principale</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Questo schermo estende un altro schermo</translation>
    </message>
    <message>
        <source>This screen clones another display</source>
        <translation type="vanished">Questo schermo clona un altro schermo</translation>
    </message>
    <message>
        <source>Right of...</source>
        <translation type="vanished">A destra di...</translation>
    </message>
    <message>
        <source>Left of...</source>
        <translation type="vanished">A sinistra di...</translation>
    </message>
    <message>
        <source>Above...</source>
        <translation type="vanished">Sopra...</translation>
    </message>
    <message>
        <source>Below...</source>
        <translation type="vanished">Sotto...</translation>
    </message>
    <message>
        <source>Positioned manually</source>
        <translation type="vanished">Posizionato manualmente</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Intervallo di aggiornamento:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Rotazione:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Informazioni sullo schermo</translation>
    </message>
    <message>
        <source>Rate:</source>
        <translation type="vanished">Frequenza:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Posizione:</translation>
    </message>
    <message>
        <source>Brightness:</source>
        <translation type="vanished">Luminosità:</translation>
    </message>
    <message>
        <source>Backlight:</source>
        <translation type="vanished">Retroilluminazione:</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="vanished">Auto</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Nome: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Produttore: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Seriale: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Dimensioni dello schermo: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Numero di serie: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>ID di dispositivo EISA: %1</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>Nessuna</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation>Inversa</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="254"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Auto</source>
        <translation type="vanished">Auto</translation>
    </message>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Impostazioni del monitor</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="obsolete">Opzioni veloci</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Impostazioni</translation>
    </message>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Gestisci le impostazioni salvate</translation>
    </message>
</context>
<context>
    <name>QuickOptions</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Impostazioni del monitor</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="obsolete">Unifica uscite</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="obsolete">Vista estesa</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="obsolete">Spegni monitor portatile LCD e usa solo monitor esterno</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="obsolete">Spegni monitor esterno e usa solo monitor LCD</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Impostazioni del monitor</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Le impostazioni sono cambiate</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Vuoi mantenere questa configurazione?</translation>
    </message>
    <message>
        <source>%1 second(s) remaining</source>
        <translation type="vanished">%1 secondi rimanenti</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>%1 secondo rimanente</numerusform>
            <numerusform>%1 secondi rimanenti</numerusform>
        </translation>
    </message>
</context>
</TS>
